@@ -13,14 +13,15 @@ default_db_path = app_dir + "pydatasci_db.sqlite3"
 
 
 def check_exists_folder():
-	app_dir_exists = os.path.exists(app_dir)
+	# If Windows does not have permission to read the folder, it will fail when trailing slashes \\ provided.
+	app_dir_exists = os.path.exists(app_dir_free)
 	if app_dir_exists:
 		print("\n=> Success - the following file path already exists on your system:\n" + app_dir + "\n")
+		return True
 	else:
 		print("\n=> Error - the following file path does not exist on your system:\n" + app_dir + "\n")
 		print("\n=> Fix - you can attempt to fix this by running `pds.create_folder()`.\n")
-
-	return app_dir_exists
+		return False
 
 
 def create_folder():
@@ -69,10 +70,12 @@ def check_permissions_folder():
 
 
 def grant_permissions_folder():
+	# Originally, I was checking permissions and only proceeding if they weren't already set...
+	# ...but this is a showstopper so I always want this to run.
 	try:
 		if os.name == 'nt':
-			# Windows icalcs permissions: https://www.educative.io/edpresso/what-is-chmod-in-windows
-			# ToDo - test on a Windows machine and mess with permissions before and after db file creation.
+			# Windows ICACLS permissions: https://www.educative.io/edpresso/what-is-chmod-in-windows
+			# Works in Windows Command Prompt and `os.system()`, but not PowerShell.
 			command = 'icacls "' + app_dir + '" /grant users:(F) /t /c'
 			sys_response = os.system(command)
 		else:
